@@ -13,7 +13,7 @@ use Test::Builder;
 use File::Find;
 use Scalar::Util qw(blessed);
 
-our $VERSION = '1.41_01';
+our $VERSION = '1.41_02';
 our $VERBOSE = 1;
 our $HOME;
 our $test_bool = 1;
@@ -247,7 +247,7 @@ sub _check_manifest {
     $test->diag($dup)  if scalar @dup_files  >= 1 and $test_bool == 1 and $VERBOSE;
 
     $test->diag( "MANIFEST: $manifest" ) if !$success;
-    if ( !$success && $^O eq 'Win32' ) {
+    if ( !$success ) {
         use Data::Dumper;
         $test->diag( Dumper([ $existing_files, $manifest_files, $excluded ]) );
     }
@@ -386,7 +386,7 @@ Test::CheckManifest - Check if your Manifest matches your distro
 
 =head1 VERSION
 
-version 1.41_01
+version 1.41_02
 
 =head1 SYNOPSIS
 
